@@ -19,8 +19,12 @@ with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef __METADATA_WIDGET_H__
 #define __METADATA_WIDGET_H__
 
-#include <gtk/gtkmenuitem.h>
+#include <gtk/gtk.h>
+#if GTK_CHECK_VERSION(3, 0, 0)
+#include <libdbusmenu-gtk3/menuitem.h>
+#else
 #include <libdbusmenu-gtk/menuitem.h>
+#endif
 
 G_BEGIN_DECLS
 
@@ -35,11 +39,11 @@ typedef struct _MetadataWidget      MetadataWidget;
 typedef struct _MetadataWidgetClass MetadataWidgetClass;
 
 struct _MetadataWidgetClass {
-    GtkMenuItemClass parent_class;
+  GtkMenuItemClass parent_class;
 };
 
 struct _MetadataWidget {
-    GtkMenuItem parent;
+  GtkMenuItem parent;
 };
 
 GType metadata_widget_get_type (void);
